@@ -28,7 +28,6 @@
 
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <gio/gio.h>
-#include <gconf/gconf-client.h>
 
 G_BEGIN_DECLS
 
@@ -81,7 +80,6 @@ typedef enum
 #define NAUTILUS_PREFERENCES_ALWAYS_USE_LOCATION_ENTRY		"always-use-location-entry"
 
 /* Which views should be displayed for new windows */
-#define NAUTILUS_WINDOW_STATE_START_WITH_LOCATION_BAR		"start-with-location-bar"
 #define NAUTILUS_WINDOW_STATE_START_WITH_STATUS_BAR		"start-with-status-bar"
 #define NAUTILUS_WINDOW_STATE_START_WITH_SIDEBAR		"start-with-sidebar"
 #define NAUTILUS_WINDOW_STATE_START_WITH_TOOLBAR		"start-with-toolbar"
@@ -113,7 +111,6 @@ enum
 
 
 /* Icon View */
-#define NAUTILUS_PREFERENCES_ICON_VIEW_DEFAULT_USE_TIGHTER_LAYOUT	"default-use-tighter-layout"
 #define NAUTILUS_PREFERENCES_ICON_VIEW_DEFAULT_ZOOM_LEVEL		"default-zoom-level"
 
 #define NAUTILUS_PREFERENCES_ICON_VIEW_LABELS_BESIDE_ICONS		"labels-beside-icons"
@@ -204,8 +201,6 @@ GSettings *nautilus_window_state;
 GSettings *gnome_lockdown_preferences;
 GSettings *gnome_background_preferences;
 
-GConfClient *nautilus_gconf_client;
-
 G_END_DECLS
 
 #endif /* NAUTILUS_GLOBAL_PREFERENCES_H */
